--- loncom/automation/batchcreatecourse.pm 2013/12/25 09:52:47 1.39
+++ loncom/automation/batchcreatecourse.pm 2016/09/01 01:05:05 1.40.2.1
@@ -1,5 +1,5 @@
#
-# $Id: batchcreatecourse.pm,v 1.39 2013/12/25 09:52:47 raeburn Exp $
+# $Id: batchcreatecourse.pm,v 1.40.2.1 2016/09/01 01:05:05 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -83,6 +83,7 @@ use strict;
#
# 1
# 1
+# 1
# 0
# keyadmin:msu
# 1
@@ -152,7 +153,7 @@ use strict;
#
# Many of these are binary options (corresponding to either checkboxes or
# radio buttons in the interactive CCRS page). Examples include:
# setpolicy, setcontent, setkeys, disableresdis, disablechat, openall,
# uniquecode
#
# A value of 1 between opening and closing tags is equivalent to a
@@ -266,7 +267,7 @@ sub parse_coursereqs {
my $xlist = 0;
my $userkey = '';
my $role = '';
- my @items = ('title','optional_id','coursecode','defaultcredits','coursehome','reshome','nonstandard','adds','drops','topmap','firstres','clonecrs','clonedom','datemode','dateshift','showphotos','setpolicy','setcontent','setkeys','keyauth','disresdis','disablechat','openall','notify_owner','notify_dc','crstype','crsquota','uniquecode');
+ my @items = ('title','optional_id','coursecode','defaultcredits','coursehome','reshome','nonstandard','adds','drops','topmap','firstres','clonecrs','clonedom','datemode','dateshift','showphotos','setpolicy','setcontent','setcomment','setkeys','keyauth','disresdis','disablechat','openall','notify_owner','notify_dc','crstype','crsquota','uniquecode');
my @possroles = qw(st ad ep ta in cc co);
my @dateitems = ('enrollstart','enrollend','accessstart','accessend');
my @useritems = ('autharg','authtype','firstname','generation','lastname','middlename','studentID');
@@ -534,6 +535,7 @@ sub build_course {
endaccess => $details->{'accessend'},
setpolicy => $details->{'setpolicy'},
setcontent => $details->{'setcontent'},
+ setcomment => $details->{'setcomment'},
reshome => $reshome,
setkeys => $details->{'setkeys'},
keyauth => $details->{'keyauth'},
@@ -542,6 +544,9 @@ sub build_course {
openall => $details->{'openall'},
firstres => $firstres
};
+ if ($details->{'textbook'}) {
+ $courseargs->{'textbook'} = $details->{'textbook'};
+ }
my %host_servers = &Apache::lonnet::get_servers($cdom,'library');
if (! exists($host_servers{$details->{'coursehome'}})) {
$$logmsg .= &mt('Invalid home server for course').': '.$details->{'coursehome'};
@@ -152,7 +153,7 @@ use strict;
# Many of these are binary options (corresponding to either checkboxes or
# radio buttons in the interactive CCRS page). Examples include:
-# setpolicy, setcontent, setkeys, disableresdis, disablechat, openall,
+# setpolicy, setcontent, setcomment, setkeys, disableresdis, disablechat, openall,
# uniquecode
#